==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/kdenotify/translations/kdenotify_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="127"/>
        <source>Qmmp now playing:</source>
        <translation>Qmmp 현재 재생중:</translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="29"/>
        <source>KDE notification plugin</source>
        <translation>KDE 알림 플러그인</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="49"/>
        <source>About KDE Notification Plugin</source>
        <translation>KDE 알림 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="50"/>
        <source>KDE notification plugin for Qmmp</source>
        <translation>Qmmp용 KDE 알림 플러그인</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation>KDE 4 알림 플러그인 설정</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay:</source>
        <translation>알림 지연:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>s</source>
        <translation>초</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Update visible notification instead create new</source>
        <translation>표시되는 알림 업데이트 대신 새 알림 만들기</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Volume change notification</source>
        <translation>볼륨 변경 알림</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Appearance</source>
        <translation>모양새</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Show covers</source>
        <translation>표지 표시</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Edit template</source>
        <translation>템플릿 편집</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="77"/>
        <source>Notification Template</source>
        <translation>알림 템플릿</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.2.orig.tar.bz2: qmmp-2.2.2/src/plugins/General/kdenotify/translations/kdenotify_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="120"/>
        <source>Qmmp now playing:</source>
        <translation>Qmmp 현재 재생중:</translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="29"/>
        <source>KDE notification plugin</source>
        <translation>KDE 알림 플러그인</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="49"/>
        <source>About KDE Notification Plugin</source>
        <translation>KDE 알림 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="50"/>
        <source>KDE notification plugin for Qmmp</source>
        <translation>Qmmp용 KDE 알림 플러그인</translation>
    </message>
</context>
<context>
    <name>KdeNotifySettingsDialog</name>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="14"/>
        <source>KDE Notification Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="45"/>
        <source>Notification delay:</source>
        <translation>알림 지연:</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="52"/>
        <source>Update visible notification instead create new</source>
        <translation>표시되는 알림 업데이트 대신 새 알림 만들기</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="72"/>
        <source>s</source>
        <translation>초</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="85"/>
        <source>Volume change notification</source>
        <translation>볼륨 변경 알림</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="95"/>
        <source>Appearance</source>
        <translation>모양새</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="101"/>
        <source>Show covers</source>
        <translation>표지 표시</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.ui" line="110"/>
        <source>Edit template</source>
        <translation>템플릿 편집</translation>
    </message>
    <message>
        <location filename="../kdenotifysettingsdialog.cpp" line="76"/>
        <source>Notification Template</source>
        <translation>알림 템플릿</translation>
    </message>
</context>
</TS>
